@@ -1,13 +1,14 @@
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
+import os
 from logging import Handler
 
-from slicklog.remotelogger import SlickLogRemoteLogger
-from slicklog.remotelogger import ConnectionBuilder
-from slicklog.util import log
-from slicklog.util import is_debug_enabled
-from slicklog.util import set_debug
+from .remotelogger import SlickLogRemoteLogger
+from .remotelogger import ConnectionBuilder
+from .util import log
+from .util import is_debug_enabled
+from .util import set_debug
 
 
 DEFAULT_LOG_GROUP_NAME = 'Default Log Group'
@@ -62,8 +63,8 @@ class SlickLogHandler(Handler):
     try:
       message = self.format(record)
       self.remote_logger.log(message)
-      if not '\n' in message[-1]:
-        self.remote_logger.log('\n')
+      if not message.endswith(os.linesep):
+        self.remote_logger.log(os.linesep)
     except Exception as ex:
       log('An error occurred while logging: {0}', str(ex))
       self.handleError(record)
