@@ -5,12 +5,12 @@ from threading import Thread
 from time import sleep
 from time import time
 
-from slicklog.util import log
-from slicklog.util import u
-from slicklog.util import new_queue
-from slicklog.util import queue_mod
-from slicklog.util import httplib_mod
-from slicklog.util import quote_p
+from .util import log
+from .util import u
+from .util import new_queue
+from .util import queue_mod
+from .util import httplib_mod
+from .util import quote_p
 
 
 class ConnectionBuilder:
@@ -106,7 +106,7 @@ class ConnectionBuilder:
 
 class SlickLogRemoteLogger:
 
-  __CONN_TIMEOUT = 20
+  __CONN_TIMEOUT = 10
   __REMOTE_LOGGER_SPAWNER_THREAD_NAME = 'SlicklLogRemoteLoggerSpawner'
   __REMOTE_LOGGER_THREAD_NAME = 'SlicklLogRemoteLogger'
   __PUSH_MAX_WAIT_SECS = 10
@@ -207,9 +207,7 @@ class SlickLogRemoteLogger:
       log('An error occurred while closing connection: {0}', str(ex))
 
   @staticmethod
-  def _timeout_passed(conn, start_time):
-    if conn is None:
-      return False
+  def _timeout_passed(start_time):
     now = time()
     elapsed = now - start_time
     log('Elapsed from connection start {0}secs', elapsed)
@@ -224,14 +222,14 @@ class SlickLogRemoteLogger:
       size = 0
       start_time = time()
       buf = []
-      while size < max_size and not self._timeout_passed(conn, start_time):
+      while size < max_size and not self._timeout_passed(start_time):
         try:
           log('Getting message from queue')
           bytes = self.log_queue.get(True, SlickLogRemoteLogger.__MAX_QUEUE_WAIT)
           log('pushing message {0}', bytes)
         except queue_mod().Empty:
           log('Queue is empty. Wait timeout expired')
-          break
+          continue
         buf.append(bytes)
         size += len(bytes)
         buf_size += len(bytes)
